@@ -146,6 +146,11 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
             for header, value in response.getheaders():
                 resp[header] = value
 
+            for header in proxy_server.HOP_BY_HOP:
+                del resp[header]
+
+            resp[proxy_server.HEADER_SERVER] = proxy_server.VALUE_SERVER
+
             return resp
 
         if response.status == 204:
@@ -157,6 +162,11 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
             for header, value in response.getheaders():
                 resp[header] = value
 
+            for header in proxy_server.HOP_BY_HOP:
+                del resp[header]
+
+            resp[proxy_server.HEADER_SERVER] = proxy_server.VALUE_SERVER
+
             return resp
         else:
             try:
@@ -174,6 +184,11 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
             for header, value in response.getheaders():
                 resp[header] = value
 
+            for header in proxy_server.HOP_BY_HOP:
+                del resp[header]
+
+            resp[proxy_server.HEADER_SERVER] = proxy_server.VALUE_SERVER
+
             return resp
 
     except:
